@@ -26,7 +26,7 @@ class TQLabel;
 
 class InfoDialog : public KDialogBase 
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
@@ -41,5 +41,3 @@ class InfoDialog : public KDialogBase
 };
 
 #endif
-
-// vim:sw=4:sts=4:ts=8:noet
