@@ -12,7 +12,7 @@ namespace KImageViewer { class Viewer; }
 
 class KViewEffects : public KParts::Plugin
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KViewEffects( TQObject* parent, const char* name, const TQStringList & );
